# (c) Copyright by Yar.
#
# Source file generated automatically.
# fmt: off


data = {
  "whole": ([
    (dict(gender="masculine", number="singular", case="nominative"), "ці́лий"),
    (dict(gender="feminine", number="singular", case="nominative"), "ці́ла"),
    (dict(gender="neuter", number="singular", case="nominative"), "ці́ле"),
    (dict(number="plural", case="nominative"), "ці́лі"),
    (dict(gender="masculine", number="singular", case="genitive"), "ці́лого"),
    (dict(gender="feminine", number="singular", case="genitive"), "ці́лої"),
    (dict(gender="neuter", number="singular", case="genitive"), "ці́лого"),
    (dict(number="plural", case="genitive"), "ці́лих"),
    (dict(gender="masculine", number="singular", case="dative"), "ці́лому"),
    (dict(gender="feminine", number="singular", case="dative"), "ці́лій"),
    (dict(gender="neuter", number="singular", case="dative"), "ці́лому"),
    (dict(number="plural", case="dative"), "ці́лим"),
    (dict(gender="masculine", number="singular", case="accusative", animacy="inanimate"), "ці́лий"),
    (dict(gender="masculine", number="singular", case="accusative", animacy="animate"), "ці́лого"),
    (dict(gender="feminine", number="singular", case="accusative"), "ці́лу"),
    (dict(gender="neuter", number="singular", case="accusative"), "ці́ле"),
    (dict(number="plural", case="accusative", animacy="inanimate"), "ці́лі"),
    (dict(number="plural", case="accusative", animacy="animate"), "ці́лих"),
    (dict(gender="masculine", number="singular", case="instrumental"), "ці́лим"),
    (dict(gender="feminine", number="singular"), "ці́лою"),
    (dict(gender="neuter", number="singular", case="instrumental"), "ці́лим"),
    (dict(number="plural", case="instrumental"), "ці́лими"),
    (dict(gender="masculine", number="singular", case="locative"), "ці́лому"),
    (dict(gender="masculine", number="singular", case="locative"), "ці́лім"),
    (dict(gender="feminine", number="singular"), "ці́лій"),
    (dict(gender="neuter", number="singular", case="locative"), "ці́лому"),
    (dict(gender="neuter", number="singular", case="locative"), "ці́лім"),
    (dict(number="plural", case="locative"), "ці́лих"),
  ], dict()),
}
