# (c) Copyright by Yar.
#
# Source file generated automatically.
# fmt: off


data = {
  "0": ([
    (dict(case="nominative", number="singular", gender="masculine"), "нульови́й"),
    (dict(case="nominative", number="singular", gender="feminine"), "нульова́"),
    (dict(case="nominative", number="singular", gender="neuter"), "нульове́"),
    (dict(case="nominative", number="plural"), "нульові́"),
    (dict(case="vocative", number="singular", gender="masculine"), "нульови́й"),
    (dict(case="vocative", number="singular", gender="feminine"), "нульова́"),
    (dict(case="vocative", number="singular", gender="neuter"), "нульове́"),
    (dict(case="vocative", number="plural"), "нульові́"),
    (dict(case="genitive", number="singular", gender="masculine"), "нульово́го"),
    (dict(case="genitive", number="singular", gender="feminine"), "нульово́ї"),
    (dict(case="genitive", number="singular", gender="neuter"), "нульово́го"),
    (dict(case="genitive", number="plural"), "нульови́х"),
    (dict(case="dative", number="singular", gender="masculine"), "нульово́му"),
    (dict(case="dative", number="singular", gender="feminine"), "нульові́й"),
    (dict(case="dative", number="singular", gender="neuter"), "нульово́му"),
    (dict(case="dative", number="plural"), "нульови́м"),
    (dict(case="accusative", number="singular", gender="masculine"), "нульови́й"),
    (dict(case="accusative", number="singular", gender="masculine"), "нульово́го"),
    (dict(case="accusative", number="singular", gender="feminine"), "нульову́"),
    (dict(case="accusative", number="singular", gender="neuter"), "нульове́"),
    (dict(case="accusative", number="plural"), "нульові́"),
    (dict(case="accusative", number="plural"), "нульови́х"),
    (dict(case="instrumental", number="singular", gender="masculine"), "нульови́м"),
    (dict(case="instrumental", number="singular", gender="feminine"), "нульово́ю"),
    (dict(case="instrumental", number="singular", gender="neuter"), "нульови́м"),
    (dict(case="instrumental", number="plural"), "нульови́ми"),
    (dict(case="locative", number="singular", gender="masculine"), "нульово́му"),
    (dict(case="locative", number="singular", gender="masculine"), "нульові́м"),
    (dict(case="locative", number="singular", gender="feminine"), "нульові́й"),
    (dict(case="locative", number="singular", gender="neuter"), "нульово́му"),
    (dict(case="locative", number="singular", gender="neuter"), "нульові́м"),
    (dict(case="locative", number="plural"), "нульови́х"),
  ], dict()),
  "1": ([
    (dict(case="nominative", number="singular", gender="masculine"), "пе́рший"),
    (dict(case="nominative", number="singular", gender="feminine"), "пе́рша"),
    (dict(case="nominative", number="singular", gender="neuter"), "пе́рше"),
    (dict(case="nominative", number="plural"), "пе́рші"),
    (dict(case="vocative", number="singular", gender="masculine"), "пе́рший"),
    (dict(case="vocative", number="singular", gender="feminine"), "пе́рша"),
    (dict(case="vocative", number="singular", gender="neuter"), "пе́рше"),
    (dict(case="vocative", number="plural"), "пе́рші"),
    (dict(case="genitive", number="singular", gender="masculine"), "пе́ршого"),
    (dict(case="genitive", number="singular", gender="feminine"), "пе́ршої"),
    (dict(case="genitive", number="singular", gender="neuter"), "пе́ршого"),
    (dict(case="genitive", number="plural"), "пе́рших"),
    (dict(case="dative", number="singular", gender="masculine"), "пе́ршому"),
    (dict(case="dative", number="singular", gender="feminine"), "пе́ршій"),
    (dict(case="dative", number="singular", gender="neuter"), "пе́ршому"),
    (dict(case="dative", number="plural"), "пе́ршим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "пе́рший"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "пе́ршого"),
    (dict(case="accusative", number="singular", gender="feminine"), "пе́ршу"),
    (dict(case="accusative", number="singular", gender="neuter"), "пе́рше"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "пе́рші"),
    (dict(case="accusative", number="plural", animacy="animate"), "пе́рших"),
    (dict(case="instrumental", number="singular", gender="masculine"), "пе́ршим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "пе́ршою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "пе́ршим"),
    (dict(case="instrumental", number="plural"), "пе́ршими"),
    (dict(case="locative", number="singular", gender="masculine"), "пе́ршому"),
    (dict(case="locative", number="singular", gender="masculine"), "пе́ршім"),
    (dict(case="locative", number="singular", gender="feminine"), "пе́ршій"),
    (dict(case="locative", number="singular", gender="neuter"), "пе́ршому"),
    (dict(case="locative", number="singular", gender="neuter"), "пе́ршім"),
    (dict(case="locative", number="plural"), "пе́рших"),
  ], dict()),
  "2": ([
    (dict(case="nominative", number="singular", gender="masculine"), "дру́гий"),
    (dict(case="nominative", number="singular", gender="feminine"), "дру́га"),
    (dict(case="nominative", number="singular", gender="neuter"), "дру́ге"),
    (dict(case="nominative", number="plural"), "дру́гі"),
    (dict(case="vocative", number="singular", gender="masculine"), "дру́гий"),
    (dict(case="vocative", number="singular", gender="feminine"), "дру́га"),
    (dict(case="vocative", number="singular", gender="neuter"), "дру́ге"),
    (dict(case="vocative", number="plural"), "дру́гі"),
    (dict(case="genitive", number="singular", gender="masculine"), "дру́гого"),
    (dict(case="genitive", number="singular", gender="feminine"), "дру́гої"),
    (dict(case="genitive", number="singular", gender="neuter"), "дру́гого"),
    (dict(case="genitive", number="plural"), "дру́гих"),
    (dict(case="dative", number="singular", gender="masculine"), "дру́гому"),
    (dict(case="dative", number="singular", gender="feminine"), "дру́гій"),
    (dict(case="dative", number="singular", gender="neuter"), "дру́гому"),
    (dict(case="dative", number="plural"), "дру́гим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "дру́гий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "дру́гого"),
    (dict(case="accusative", number="singular", gender="feminine"), "дру́гу"),
    (dict(case="accusative", number="singular", gender="neuter"), "дру́ге"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "дру́гі"),
    (dict(case="accusative", number="plural", animacy="animate"), "дру́гих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "дру́гим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "дру́гою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "дру́гим"),
    (dict(case="instrumental", number="plural"), "дру́гими"),
    (dict(case="locative", number="singular", gender="masculine"), "дру́гому"),
    (dict(case="locative", number="singular", gender="masculine"), "дру́гім"),
    (dict(case="locative", number="singular", gender="feminine"), "дру́гій"),
    (dict(case="locative", number="singular", gender="neuter"), "дру́гому"),
    (dict(case="locative", number="singular", gender="neuter"), "дру́гім"),
    (dict(case="locative", number="plural"), "дру́гих"),
  ], dict()),
  "3": ([
    (dict(case="nominative", number="singular", gender="masculine"), "тре́тій"),
    (dict(case="nominative", number="singular", gender="feminine"), "тре́тя"),
    (dict(case="nominative", number="singular", gender="neuter"), "тре́тє"),
    (dict(case="nominative", number="plural"), "тре́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "тре́тій"),
    (dict(case="vocative", number="singular", gender="feminine"), "тре́тя"),
    (dict(case="vocative", number="singular", gender="neuter"), "тре́тє"),
    (dict(case="vocative", number="plural"), "тре́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "тре́тього"),
    (dict(case="genitive", number="singular", gender="feminine"), "тре́тьої"),
    (dict(case="genitive", number="singular", gender="neuter"), "тре́тього"),
    (dict(case="genitive", number="plural"), "тре́тіх"),
    (dict(case="dative", number="singular", gender="masculine"), "тре́тьому"),
    (dict(case="dative", number="singular", gender="feminine"), "тре́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "тре́тьому"),
    (dict(case="dative", number="plural"), "тре́тім"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "тре́тій"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "тре́тього"),
    (dict(case="accusative", number="singular", gender="feminine"), "тре́тю"),
    (dict(case="accusative", number="singular", gender="neuter"), "тре́тє"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "тре́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "тре́тіх"),
    (dict(case="instrumental", number="singular", gender="masculine"), "тре́тім"),
    (dict(case="instrumental", number="singular", gender="feminine"), "тре́тьою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "тре́тім"),
    (dict(case="instrumental", number="plural"), "тре́тіми"),
    (dict(case="locative", number="singular", gender="masculine"), "тре́тьому"),
    (dict(case="locative", number="singular", gender="masculine"), "тре́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "тре́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "тре́тьому"),
    (dict(case="locative", number="singular", gender="neuter"), "тре́тім"),
    (dict(case="locative", number="plural"), "тре́тіх"),
  ], dict()),
  "4": ([
    (dict(case="nominative", number="singular", gender="masculine"), "четве́ртий"),
    (dict(case="nominative", number="singular", gender="feminine"), "четве́рта"),
    (dict(case="nominative", number="singular", gender="neuter"), "четве́рте"),
    (dict(case="nominative", number="plural"), "четве́рті"),
    (dict(case="vocative", number="singular", gender="masculine"), "четве́ртий"),
    (dict(case="vocative", number="singular", gender="feminine"), "четве́рта"),
    (dict(case="vocative", number="singular", gender="neuter"), "четве́рте"),
    (dict(case="vocative", number="plural"), "четве́рті"),
    (dict(case="genitive", number="singular", gender="masculine"), "четве́ртого"),
    (dict(case="genitive", number="singular", gender="feminine"), "четве́ртої"),
    (dict(case="genitive", number="singular", gender="neuter"), "четве́ртого"),
    (dict(case="genitive", number="plural"), "четве́ртих"),
    (dict(case="dative", number="singular", gender="masculine"), "четве́ртому"),
    (dict(case="dative", number="singular", gender="feminine"), "четве́ртій"),
    (dict(case="dative", number="singular", gender="neuter"), "четве́ртому"),
    (dict(case="dative", number="plural"), "четве́ртим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "четве́ртий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "четве́ртого"),
    (dict(case="accusative", number="singular", gender="feminine"), "четве́рту"),
    (dict(case="accusative", number="singular", gender="neuter"), "четве́рте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "четве́рті"),
    (dict(case="accusative", number="plural", animacy="animate"), "четве́ртих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "четве́ртим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "четве́ртою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "четве́ртим"),
    (dict(case="instrumental", number="plural"), "четве́ртими"),
    (dict(case="locative", number="singular", gender="masculine"), "четве́ртому"),
    (dict(case="locative", number="singular", gender="masculine"), "четве́ртім"),
    (dict(case="locative", number="singular", gender="feminine"), "четве́ртій"),
    (dict(case="locative", number="singular", gender="neuter"), "четве́ртому"),
    (dict(case="locative", number="singular", gender="neuter"), "четве́ртім"),
    (dict(case="locative", number="plural"), "четве́ртих"),
  ], dict()),
  "5": ([
    (dict(case="nominative", number="singular", gender="masculine"), "пʼя́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "пʼя́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "пʼя́те"),
    (dict(case="nominative", number="plural"), "пʼя́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "пʼя́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "пʼя́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "пʼя́те"),
    (dict(case="vocative", number="plural"), "пʼя́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "пʼя́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "пʼя́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "пʼя́того"),
    (dict(case="genitive", number="plural"), "пʼя́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "пʼя́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "пʼя́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "пʼя́тому"),
    (dict(case="dative", number="plural"), "пʼя́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "пʼя́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "пʼя́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "пʼя́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "пʼя́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "пʼя́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "пʼя́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "пʼя́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "пʼя́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "пʼя́тим"),
    (dict(case="instrumental", number="plural"), "пʼя́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼя́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼя́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "пʼя́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼя́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼя́тім"),
    (dict(case="locative", number="plural"), "пʼя́тих"),
  ], dict()),
  "6": ([
    (dict(case="nominative", number="singular", gender="masculine"), "шо́стий"),
    (dict(case="nominative", number="singular", gender="feminine"), "шо́ста"),
    (dict(case="nominative", number="singular", gender="neuter"), "шо́сте"),
    (dict(case="nominative", number="plural"), "шо́сті"),
    (dict(case="vocative", number="singular", gender="masculine"), "шо́стий"),
    (dict(case="vocative", number="singular", gender="feminine"), "шо́ста"),
    (dict(case="vocative", number="singular", gender="neuter"), "шо́сте"),
    (dict(case="vocative", number="plural"), "шо́сті"),
    (dict(case="genitive", number="singular", gender="masculine"), "шо́стого"),
    (dict(case="genitive", number="singular", gender="feminine"), "шо́стої"),
    (dict(case="genitive", number="singular", gender="neuter"), "шо́стого"),
    (dict(case="genitive", number="plural"), "шо́стих"),
    (dict(case="dative", number="singular", gender="masculine"), "шо́стому"),
    (dict(case="dative", number="singular", gender="feminine"), "шо́стій"),
    (dict(case="dative", number="singular", gender="neuter"), "шо́стому"),
    (dict(case="dative", number="plural"), "шо́стим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "шо́стий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "шо́стого"),
    (dict(case="accusative", number="singular", gender="feminine"), "шо́сту"),
    (dict(case="accusative", number="singular", gender="neuter"), "шо́сте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "шо́сті"),
    (dict(case="accusative", number="plural", animacy="animate"), "шо́стих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "шо́стим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "шо́стою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "шо́стим"),
    (dict(case="instrumental", number="plural"), "шо́стими"),
    (dict(case="locative", number="singular", gender="masculine"), "шо́стому"),
    (dict(case="locative", number="singular", gender="masculine"), "шо́стім"),
    (dict(case="locative", number="singular", gender="feminine"), "шо́стій"),
    (dict(case="locative", number="singular", gender="neuter"), "шо́стому"),
    (dict(case="locative", number="singular", gender="neuter"), "шо́стім"),
    (dict(case="locative", number="plural"), "шо́стих"),
  ], dict()),
  "7": ([
    (dict(case="nominative", number="singular", gender="masculine"), "сьо́мий"),
    (dict(case="nominative", number="singular", gender="feminine"), "сьо́ма"),
    (dict(case="nominative", number="singular", gender="neuter"), "сьо́ме"),
    (dict(case="nominative", number="plural"), "сьо́мі"),
    (dict(case="vocative", number="singular", gender="masculine"), "сьо́мий"),
    (dict(case="vocative", number="singular", gender="feminine"), "сьо́ма"),
    (dict(case="vocative", number="singular", gender="neuter"), "сьо́ме"),
    (dict(case="vocative", number="plural"), "сьо́мі"),
    (dict(case="genitive", number="singular", gender="masculine"), "сьо́мого"),
    (dict(case="genitive", number="singular", gender="feminine"), "сьо́мої"),
    (dict(case="genitive", number="singular", gender="neuter"), "сьо́мого"),
    (dict(case="genitive", number="plural"), "сьо́мих"),
    (dict(case="dative", number="singular", gender="masculine"), "сьо́мому"),
    (dict(case="dative", number="singular", gender="feminine"), "сьо́мій"),
    (dict(case="dative", number="singular", gender="neuter"), "сьо́мому"),
    (dict(case="dative", number="plural"), "сьо́мим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "сьо́мий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "сьо́мого"),
    (dict(case="accusative", number="singular", gender="feminine"), "сьо́му"),
    (dict(case="accusative", number="singular", gender="neuter"), "сьо́ме"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "сьо́мі"),
    (dict(case="accusative", number="plural", animacy="animate"), "сьо́мих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "сьо́мим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "сьо́мою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "сьо́мим"),
    (dict(case="instrumental", number="plural"), "сьо́мими"),
    (dict(case="locative", number="singular", gender="masculine"), "сьо́мому"),
    (dict(case="locative", number="singular", gender="masculine"), "сьо́мім"),
    (dict(case="locative", number="singular", gender="feminine"), "сьо́мій"),
    (dict(case="locative", number="singular", gender="neuter"), "сьо́мому"),
    (dict(case="locative", number="singular", gender="neuter"), "сьо́мім"),
    (dict(case="locative", number="plural"), "сьо́мих"),
  ], dict()),
  "8": ([
    (dict(case="nominative", number="singular", gender="masculine"), "во́сьмий"),
    (dict(case="nominative", number="singular", gender="feminine"), "во́сьма"),
    (dict(case="nominative", number="singular", gender="neuter"), "во́сьме"),
    (dict(case="nominative", number="plural"), "во́сьмі"),
    (dict(case="vocative", number="singular", gender="masculine"), "во́сьмий"),
    (dict(case="vocative", number="singular", gender="feminine"), "во́сьма"),
    (dict(case="vocative", number="singular", gender="neuter"), "во́сьме"),
    (dict(case="vocative", number="plural"), "во́сьмі"),
    (dict(case="genitive", number="singular", gender="masculine"), "во́сьмого"),
    (dict(case="genitive", number="singular", gender="feminine"), "во́сьмої"),
    (dict(case="genitive", number="singular", gender="neuter"), "во́сьмого"),
    (dict(case="genitive", number="plural"), "во́сьмих"),
    (dict(case="dative", number="singular", gender="masculine"), "во́сьмому"),
    (dict(case="dative", number="singular", gender="feminine"), "во́сьмій"),
    (dict(case="dative", number="singular", gender="neuter"), "во́сьмому"),
    (dict(case="dative", number="plural"), "во́сьмим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "во́сьмий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "во́сьмого"),
    (dict(case="accusative", number="singular", gender="feminine"), "во́сьму"),
    (dict(case="accusative", number="singular", gender="neuter"), "во́сьме"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "во́сьмі"),
    (dict(case="accusative", number="plural", animacy="animate"), "во́сьмих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "во́сьмим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "во́сьмою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "во́сьмим"),
    (dict(case="instrumental", number="plural"), "во́сьмими"),
    (dict(case="locative", number="singular", gender="masculine"), "во́сьмому"),
    (dict(case="locative", number="singular", gender="masculine"), "во́сьмім"),
    (dict(case="locative", number="singular", gender="feminine"), "во́сьмій"),
    (dict(case="locative", number="singular", gender="neuter"), "во́сьмому"),
    (dict(case="locative", number="singular", gender="neuter"), "во́сьмім"),
    (dict(case="locative", number="plural"), "во́сьмих"),
  ], dict()),
  "9": ([
    (dict(case="nominative", number="singular", gender="masculine"), "девʼя́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "девʼя́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "девʼя́те"),
    (dict(case="nominative", number="plural"), "девʼя́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "девʼя́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "девʼя́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "девʼя́те"),
    (dict(case="vocative", number="plural"), "девʼя́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "девʼя́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "девʼя́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "девʼя́того"),
    (dict(case="genitive", number="plural"), "девʼя́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "девʼя́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "девʼя́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "девʼя́тому"),
    (dict(case="dative", number="plural"), "девʼя́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "девʼя́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "девʼя́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "девʼя́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "девʼя́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "девʼя́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "девʼя́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "девʼя́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "девʼя́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "девʼя́тим"),
    (dict(case="instrumental", number="plural"), "девʼя́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼя́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼя́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "девʼя́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼя́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼя́тім"),
    (dict(case="locative", number="plural"), "девʼя́тих"),
  ], dict()),
  "10": ([
    (dict(case="nominative", number="singular", gender="masculine"), "деся́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "деся́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "деся́те"),
    (dict(case="nominative", number="plural"), "деся́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "деся́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "деся́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "деся́те"),
    (dict(case="vocative", number="plural"), "деся́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "деся́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "деся́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "деся́того"),
    (dict(case="genitive", number="plural"), "деся́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "деся́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "деся́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "деся́тому"),
    (dict(case="dative", number="plural"), "деся́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "деся́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "деся́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "деся́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "деся́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "деся́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "деся́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "деся́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "деся́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "деся́тим"),
    (dict(case="instrumental", number="plural"), "деся́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "деся́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "деся́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "деся́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "деся́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "деся́тім"),
    (dict(case="locative", number="plural"), "деся́тих"),
  ], dict()),
  "11": ([
    (dict(case="nominative", number="singular", gender="masculine"), "одина́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "одина́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "одина́дцяте"),
    (dict(case="nominative", number="plural"), "одина́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "одина́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "одина́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "одина́дцяте"),
    (dict(case="vocative", number="plural"), "одина́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "одина́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "одина́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "одина́дцятого"),
    (dict(case="genitive", number="plural"), "одина́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "одина́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "одина́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "одина́дцятому"),
    (dict(case="dative", number="plural"), "одина́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "одина́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "одина́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "одина́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "одина́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "одина́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "одина́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "одина́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "одина́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "одина́дцятим"),
    (dict(case="instrumental", number="plural"), "одина́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "одина́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "одина́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "одина́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "одина́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "одина́дцятім"),
    (dict(case="locative", number="plural"), "одина́дцятих"),
  ], dict()),
  "12": ([
    (dict(case="nominative", number="singular", gender="masculine"), "двана́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "двана́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "двана́дцяте"),
    (dict(case="nominative", number="plural"), "двана́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "двана́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "двана́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "двана́дцяте"),
    (dict(case="vocative", number="plural"), "двана́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "двана́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "двана́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "двана́дцятого"),
    (dict(case="genitive", number="plural"), "двана́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "двана́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "двана́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "двана́дцятому"),
    (dict(case="dative", number="plural"), "двана́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "двана́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "двана́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "двана́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "двана́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "двана́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "двана́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "двана́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "двана́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "двана́дцятим"),
    (dict(case="instrumental", number="plural"), "двана́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "двана́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "двана́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "двана́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "двана́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "двана́дцятім"),
    (dict(case="locative", number="plural"), "двана́дцятих"),
  ], dict()),
  "13": ([
    (dict(case="nominative", number="singular", gender="masculine"), "трина́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "трина́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "трина́дцяте"),
    (dict(case="nominative", number="plural"), "трина́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "трина́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "трина́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "трина́дцяте"),
    (dict(case="vocative", number="plural"), "трина́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "трина́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "трина́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "трина́дцятого"),
    (dict(case="genitive", number="plural"), "трина́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "трина́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "трина́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "трина́дцятому"),
    (dict(case="dative", number="plural"), "трина́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "трина́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "трина́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "трина́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "трина́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "трина́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "трина́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "трина́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "трина́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "трина́дцятим"),
    (dict(case="instrumental", number="plural"), "трина́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "трина́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "трина́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "трина́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "трина́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "трина́дцятім"),
    (dict(case="locative", number="plural"), "трина́дцятих"),
  ], dict()),
  "14": ([
    (dict(case="nominative", number="singular", gender="masculine"), "чотирна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "чотирна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "чотирна́дцяте"),
    (dict(case="nominative", number="plural"), "чотирна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "чотирна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "чотирна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "чотирна́дцяте"),
    (dict(case="vocative", number="plural"), "чотирна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "чотирна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "чотирна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "чотирна́дцятого"),
    (dict(case="genitive", number="plural"), "чотирна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "чотирна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "чотирна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "чотирна́дцятому"),
    (dict(case="dative", number="plural"), "чотирна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "чотирна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "чотирна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "чотирна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "чотирна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "чотирна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "чотирна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "чотирна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "чотирна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "чотирна́дцятим"),
    (dict(case="instrumental", number="plural"), "чотирна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "чотирна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "чотирна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "чотирна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "чотирна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "чотирна́дцятім"),
    (dict(case="locative", number="plural"), "чотирна́дцятих"),
  ], dict()),
  "15": ([
    (dict(case="nominative", number="singular", gender="masculine"), "пʼятна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "пʼятна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "пʼятна́дцяте"),
    (dict(case="nominative", number="plural"), "пʼятна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "пʼятна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "пʼятна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "пʼятна́дцяте"),
    (dict(case="vocative", number="plural"), "пʼятна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "пʼятна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "пʼятна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "пʼятна́дцятого"),
    (dict(case="genitive", number="plural"), "пʼятна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "пʼятна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "пʼятна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "пʼятна́дцятому"),
    (dict(case="dative", number="plural"), "пʼятна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "пʼятна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "пʼятна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "пʼятна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "пʼятна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "пʼятна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "пʼятна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "пʼятна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "пʼятна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "пʼятна́дцятим"),
    (dict(case="instrumental", number="plural"), "пʼятна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "пʼятна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятна́дцятім"),
    (dict(case="locative", number="plural"), "пʼятна́дцятих"),
  ], dict()),
  "16": ([
    (dict(case="nominative", number="singular", gender="masculine"), "шістна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "шістна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "шістна́дцяте"),
    (dict(case="nominative", number="plural"), "шістна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "шістна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "шістна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "шістна́дцяте"),
    (dict(case="vocative", number="plural"), "шістна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "шістна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "шістна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "шістна́дцятого"),
    (dict(case="genitive", number="plural"), "шістна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "шістна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "шістна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "шістна́дцятому"),
    (dict(case="dative", number="plural"), "шістна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "шістна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "шістна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "шістна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "шістна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "шістна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "шістна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "шістна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "шістна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "шістна́дцятим"),
    (dict(case="instrumental", number="plural"), "шістна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "шістна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "шістна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "шістна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "шістна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "шістна́дцятім"),
    (dict(case="locative", number="plural"), "шістна́дцятих"),
  ], dict()),
  "17": ([
    (dict(case="nominative", number="singular", gender="masculine"), "сімна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "сімна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "сімна́дцяте"),
    (dict(case="nominative", number="plural"), "сімна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "сімна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "сімна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "сімна́дцяте"),
    (dict(case="vocative", number="plural"), "сімна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "сімна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "сімна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "сімна́дцятого"),
    (dict(case="genitive", number="plural"), "сімна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "сімна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "сімна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "сімна́дцятому"),
    (dict(case="dative", number="plural"), "сімна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "сімна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "сімна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "сімна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "сімна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "сімна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "сімна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "сімна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "сімна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "сімна́дцятим"),
    (dict(case="instrumental", number="plural"), "сімна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "сімна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "сімна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "сімна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "сімна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "сімна́дцятім"),
    (dict(case="locative", number="plural"), "сімна́дцятих"),
  ], dict()),
  "18": ([
    (dict(case="nominative", number="singular", gender="masculine"), "вісімна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "вісімна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "вісімна́дцяте"),
    (dict(case="nominative", number="plural"), "вісімна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "вісімна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "вісімна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "вісімна́дцяте"),
    (dict(case="vocative", number="plural"), "вісімна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "вісімна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "вісімна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "вісімна́дцятого"),
    (dict(case="genitive", number="plural"), "вісімна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "вісімна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "вісімна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "вісімна́дцятому"),
    (dict(case="dative", number="plural"), "вісімна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "вісімна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "вісімна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "вісімна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "вісімна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "вісімна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "вісімна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "вісімна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "вісімна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "вісімна́дцятим"),
    (dict(case="instrumental", number="plural"), "вісімна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "вісімна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "вісімна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "вісімна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "вісімна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "вісімна́дцятім"),
    (dict(case="locative", number="plural"), "вісімна́дцятих"),
  ], dict()),
  "19": ([
    (dict(case="nominative", number="singular", gender="masculine"), "девʼятна́дцятий"),
    (dict(case="nominative", number="singular", gender="feminine"), "девʼятна́дцята"),
    (dict(case="nominative", number="singular", gender="neuter"), "девʼятна́дцяте"),
    (dict(case="nominative", number="plural"), "девʼятна́дцяті"),
    (dict(case="vocative", number="singular", gender="masculine"), "девʼятна́дцятий"),
    (dict(case="vocative", number="singular", gender="feminine"), "девʼятна́дцята"),
    (dict(case="vocative", number="singular", gender="neuter"), "девʼятна́дцяте"),
    (dict(case="vocative", number="plural"), "девʼятна́дцяті"),
    (dict(case="genitive", number="singular", gender="masculine"), "девʼятна́дцятого"),
    (dict(case="genitive", number="singular", gender="feminine"), "девʼятна́дцятої"),
    (dict(case="genitive", number="singular", gender="neuter"), "девʼятна́дцятого"),
    (dict(case="genitive", number="plural"), "девʼятна́дцятих"),
    (dict(case="dative", number="singular", gender="masculine"), "девʼятна́дцятому"),
    (dict(case="dative", number="singular", gender="feminine"), "девʼятна́дцятій"),
    (dict(case="dative", number="singular", gender="neuter"), "девʼятна́дцятому"),
    (dict(case="dative", number="plural"), "девʼятна́дцятим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "девʼятна́дцятий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "девʼятна́дцятого"),
    (dict(case="accusative", number="singular", gender="feminine"), "девʼятна́дцяту"),
    (dict(case="accusative", number="singular", gender="neuter"), "девʼятна́дцяте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "девʼятна́дцяті"),
    (dict(case="accusative", number="plural", animacy="animate"), "девʼятна́дцятих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "девʼятна́дцятим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "девʼятна́дцятою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "девʼятна́дцятим"),
    (dict(case="instrumental", number="plural"), "девʼятна́дцятими"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼятна́дцятому"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼятна́дцятім"),
    (dict(case="locative", number="singular", gender="feminine"), "девʼятна́дцятій"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼятна́дцятому"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼятна́дцятім"),
    (dict(case="locative", number="plural"), "девʼятна́дцятих"),
  ], dict()),
  "20": ([
    (dict(case="nominative", number="singular", gender="masculine"), "двадця́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "двадця́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "двадця́те"),
    (dict(case="nominative", number="plural"), "двадця́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "двадця́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "двадця́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "двадця́те"),
    (dict(case="vocative", number="plural"), "двадця́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "двадця́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "двадця́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "двадця́того"),
    (dict(case="genitive", number="plural"), "двадця́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "двадця́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "двадця́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "двадця́тому"),
    (dict(case="dative", number="plural"), "двадця́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "двадця́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "двадця́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "двадця́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "двадця́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "двадця́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "двадця́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "двадця́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "двадця́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "двадця́тим"),
    (dict(case="instrumental", number="plural"), "двадця́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "двадця́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "двадця́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "двадця́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "двадця́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "двадця́тім"),
    (dict(case="locative", number="plural"), "двадця́тих"),
  ], dict()),
  "30": ([
    (dict(case="nominative", number="singular", gender="masculine"), "тридця́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "тридця́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "тридця́те"),
    (dict(case="nominative", number="plural"), "тридця́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "тридця́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "тридця́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "тридця́те"),
    (dict(case="vocative", number="plural"), "тридця́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "тридця́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "тридця́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "тридця́того"),
    (dict(case="genitive", number="plural"), "тридця́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "тридця́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "тридця́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "тридця́тому"),
    (dict(case="dative", number="plural"), "тридця́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "тридця́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "тридця́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "тридця́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "тридця́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "тридця́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "тридця́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "тридця́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "тридця́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "тридця́тим"),
    (dict(case="instrumental", number="plural"), "тридця́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "тридця́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "тридця́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "тридця́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "тридця́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "тридця́тім"),
    (dict(case="locative", number="plural"), "тридця́тих"),
  ], dict()),
  "40": ([
    (dict(case="nominative", number="singular", gender="masculine"), "сороко́вий"),
    (dict(case="nominative", number="singular", gender="feminine"), "сороко́ва"),
    (dict(case="nominative", number="singular", gender="neuter"), "сороко́ве"),
    (dict(case="nominative", number="plural"), "сороко́ві"),
    (dict(case="vocative", number="singular", gender="masculine"), "сороко́вий"),
    (dict(case="vocative", number="singular", gender="feminine"), "сороко́ва"),
    (dict(case="vocative", number="singular", gender="neuter"), "сороко́ве"),
    (dict(case="vocative", number="plural"), "сороко́ві"),
    (dict(case="genitive", number="singular", gender="masculine"), "сороко́вого"),
    (dict(case="genitive", number="singular", gender="feminine"), "сороко́вої"),
    (dict(case="genitive", number="singular", gender="neuter"), "сороко́вого"),
    (dict(case="genitive", number="plural"), "сороко́вих"),
    (dict(case="dative", number="singular", gender="masculine"), "сороко́вому"),
    (dict(case="dative", number="singular", gender="feminine"), "сороко́вій"),
    (dict(case="dative", number="singular", gender="neuter"), "сороко́вому"),
    (dict(case="dative", number="plural"), "сороко́вим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "сороко́вий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "сороко́вого"),
    (dict(case="accusative", number="singular", gender="feminine"), "сороко́ву"),
    (dict(case="accusative", number="singular", gender="neuter"), "сороко́ве"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "сороко́ві"),
    (dict(case="accusative", number="plural", animacy="animate"), "сороко́вих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "сороко́вим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "сороко́вою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "сороко́вим"),
    (dict(case="instrumental", number="plural"), "сороко́вими"),
    (dict(case="locative", number="singular", gender="masculine"), "сороко́вому"),
    (dict(case="locative", number="singular", gender="masculine"), "сороко́вім"),
    (dict(case="locative", number="singular", gender="feminine"), "сороко́вій"),
    (dict(case="locative", number="singular", gender="neuter"), "сороко́вому"),
    (dict(case="locative", number="singular", gender="neuter"), "сороко́вім"),
    (dict(case="locative", number="plural"), "сороко́вих"),
  ], dict()),
  "50": ([
    (dict(case="nominative", number="singular", gender="masculine"), "пʼятдеся́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "пʼятдеся́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "пʼятдеся́те"),
    (dict(case="nominative", number="plural"), "пʼятдеся́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "пʼятдеся́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "пʼятдеся́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "пʼятдеся́те"),
    (dict(case="vocative", number="plural"), "пʼятдеся́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "пʼятдеся́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "пʼятдеся́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "пʼятдеся́того"),
    (dict(case="genitive", number="plural"), "пʼятдеся́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "пʼятдеся́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "пʼятдеся́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "пʼятдеся́тому"),
    (dict(case="dative", number="plural"), "пʼятдеся́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "пʼятдеся́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "пʼятдеся́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "пʼятдеся́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "пʼятдеся́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "пʼятдеся́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "пʼятдеся́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "пʼятдеся́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "пʼятдеся́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "пʼятдеся́тим"),
    (dict(case="instrumental", number="plural"), "пʼятдеся́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятдеся́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятдеся́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "пʼятдеся́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятдеся́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятдеся́тім"),
    (dict(case="locative", number="plural"), "пʼятдеся́тих"),
  ], dict()),
  "60": ([
    (dict(case="nominative", number="singular", gender="masculine"), "шістдеся́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "шістдеся́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "шістдеся́те"),
    (dict(case="nominative", number="plural"), "шістдеся́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "шістдеся́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "шістдеся́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "шістдеся́те"),
    (dict(case="vocative", number="plural"), "шістдеся́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "шістдеся́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "шістдеся́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "шістдеся́того"),
    (dict(case="genitive", number="plural"), "шістдеся́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "шістдеся́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "шістдеся́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "шістдеся́тому"),
    (dict(case="dative", number="plural"), "шістдеся́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "шістдеся́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "шістдеся́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "шістдеся́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "шістдеся́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "шістдеся́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "шістдеся́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "шістдеся́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "шістдеся́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "шістдеся́тим"),
    (dict(case="instrumental", number="plural"), "шістдеся́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "шістдеся́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "шістдеся́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "шістдеся́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "шістдеся́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "шістдеся́тім"),
    (dict(case="locative", number="plural"), "шістдеся́тих"),
  ], dict()),
  "70": ([
    (dict(case="nominative", number="singular", gender="masculine"), "сімдеся́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "сімдеся́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "сімдеся́те"),
    (dict(case="nominative", number="plural"), "сімдеся́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "сімдеся́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "сімдеся́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "сімдеся́те"),
    (dict(case="vocative", number="plural"), "сімдеся́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "сімдеся́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "сімдеся́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "сімдеся́того"),
    (dict(case="genitive", number="plural"), "сімдеся́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "сімдеся́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "сімдеся́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "сімдеся́тому"),
    (dict(case="dative", number="plural"), "сімдеся́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "сімдеся́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "сімдеся́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "сімдеся́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "сімдеся́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "сімдеся́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "сімдеся́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "сімдеся́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "сімдеся́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "сімдеся́тим"),
    (dict(case="instrumental", number="plural"), "сімдеся́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "сімдеся́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "сімдеся́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "сімдеся́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "сімдеся́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "сімдеся́тім"),
    (dict(case="locative", number="plural"), "сімдеся́тих"),
  ], dict()),
  "80": ([
    (dict(case="nominative", number="singular", gender="masculine"), "вісімдеся́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "вісімдеся́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "вісімдеся́те"),
    (dict(case="nominative", number="plural"), "вісімдеся́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "вісімдеся́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "вісімдеся́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "вісімдеся́те"),
    (dict(case="vocative", number="plural"), "вісімдеся́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "вісімдеся́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "вісімдеся́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "вісімдеся́того"),
    (dict(case="genitive", number="plural"), "вісімдеся́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "вісімдеся́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "вісімдеся́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "вісімдеся́тому"),
    (dict(case="dative", number="plural"), "вісімдеся́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "вісімдеся́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "вісімдеся́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "вісімдеся́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "вісімдеся́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "вісімдеся́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "вісімдеся́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "вісімдеся́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "вісімдеся́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "вісімдеся́тим"),
    (dict(case="instrumental", number="plural"), "вісімдеся́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "вісімдеся́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "вісімдеся́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "вісімдеся́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "вісімдеся́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "вісімдеся́тім"),
    (dict(case="locative", number="plural"), "вісімдеся́тих"),
  ], dict()),
  "90": ([
    (dict(case="nominative", number="singular", gender="masculine"), "девʼяно́стий"),
    (dict(case="nominative", number="singular", gender="feminine"), "девʼяно́ста"),
    (dict(case="nominative", number="singular", gender="neuter"), "девʼяно́сте"),
    (dict(case="nominative", number="plural"), "девʼяно́сті"),
    (dict(case="vocative", number="singular", gender="masculine"), "девʼяно́стий"),
    (dict(case="vocative", number="singular", gender="feminine"), "девʼяно́ста"),
    (dict(case="vocative", number="singular", gender="neuter"), "девʼяно́сте"),
    (dict(case="vocative", number="plural"), "девʼяно́сті"),
    (dict(case="genitive", number="singular", gender="masculine"), "девʼяно́стого"),
    (dict(case="genitive", number="singular", gender="feminine"), "девʼяно́стої"),
    (dict(case="genitive", number="singular", gender="neuter"), "девʼяно́стого"),
    (dict(case="genitive", number="plural"), "девʼяно́стих"),
    (dict(case="dative", number="singular", gender="masculine"), "девʼяно́стому"),
    (dict(case="dative", number="singular", gender="feminine"), "девʼяно́стій"),
    (dict(case="dative", number="singular", gender="neuter"), "девʼяно́стому"),
    (dict(case="dative", number="plural"), "девʼяно́стим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "девʼяно́стий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "девʼяно́стого"),
    (dict(case="accusative", number="singular", gender="feminine"), "девʼяно́сту"),
    (dict(case="accusative", number="singular", gender="neuter"), "девʼяно́сте"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "девʼяно́сті"),
    (dict(case="accusative", number="plural", animacy="animate"), "девʼяно́стих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "девʼяно́стим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "девʼяно́стою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "девʼяно́стим"),
    (dict(case="instrumental", number="plural"), "девʼяно́стими"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼяно́стому"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼяно́стім"),
    (dict(case="locative", number="singular", gender="feminine"), "девʼяно́стій"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼяно́стому"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼяно́стім"),
    (dict(case="locative", number="plural"), "девʼяно́стих"),
  ], dict()),
  "100": ([
    (dict(case="nominative", number="singular", gender="masculine"), "со́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "со́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "со́те"),
    (dict(case="nominative", number="plural"), "со́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "со́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "со́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "со́те"),
    (dict(case="vocative", number="plural"), "со́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "со́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "со́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "со́того"),
    (dict(case="genitive", number="plural"), "со́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "со́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "со́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "со́тому"),
    (dict(case="dative", number="plural"), "со́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "со́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "со́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "со́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "со́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "со́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "со́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "со́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "со́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "со́тим"),
    (dict(case="instrumental", number="plural"), "со́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "со́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "со́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "со́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "со́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "со́тім"),
    (dict(case="locative", number="plural"), "со́тих"),
  ], dict()),
  "200": ([
    (dict(case="nominative", number="singular", gender="masculine"), "двохсо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "двохсо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "двохсо́те"),
    (dict(case="nominative", number="plural"), "двохсо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "двохсо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "двохсо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "двохсо́те"),
    (dict(case="vocative", number="plural"), "двохсо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "двохсо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "двохсо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "двохсо́того"),
    (dict(case="genitive", number="plural"), "двохсо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "двохсо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "двохсо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "двохсо́тому"),
    (dict(case="dative", number="plural"), "двохсо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "двохсо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "двохсо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "двохсо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "двохсо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "двохсо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "двохсо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "двохсо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "двохсо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "двохсо́тим"),
    (dict(case="instrumental", number="plural"), "двохсо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "двохсо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "двохсо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "двохсо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "двохсо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "двохсо́тім"),
    (dict(case="locative", number="plural"), "двохсо́тих"),
  ], dict()),
  "300": ([
    (dict(case="nominative", number="singular", gender="masculine"), "трьохсо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "трьохсо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "трьохсо́те"),
    (dict(case="nominative", number="plural"), "трьохсо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "трьохсо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "трьохсо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "трьохсо́те"),
    (dict(case="vocative", number="plural"), "трьохсо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "трьохсо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "трьохсо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "трьохсо́того"),
    (dict(case="genitive", number="plural"), "трьохсо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "трьохсо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "трьохсо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "трьохсо́тому"),
    (dict(case="dative", number="plural"), "трьохсо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "трьохсо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "трьохсо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "трьохсо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "трьохсо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "трьохсо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "трьохсо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "трьохсо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "трьохсо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "трьохсо́тим"),
    (dict(case="instrumental", number="plural"), "трьохсо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "трьохсо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "трьохсо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "трьохсо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "трьохсо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "трьохсо́тім"),
    (dict(case="locative", number="plural"), "трьохсо́тих"),
  ], dict()),
  "400": ([
    (dict(case="nominative", number="singular", gender="masculine"), "чотирьохсо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "чотирьохсо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "чотирьохсо́те"),
    (dict(case="nominative", number="plural"), "чотирьохсо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "чотирьохсо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "чотирьохсо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "чотирьохсо́те"),
    (dict(case="vocative", number="plural"), "чотирьохсо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "чотирьохсо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "чотирьохсо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "чотирьохсо́того"),
    (dict(case="genitive", number="plural"), "чотирьохсо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "чотирьохсо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "чотирьохсо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "чотирьохсо́тому"),
    (dict(case="dative", number="plural"), "чотирьохсо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "чотирьохсо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "чотирьохсо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "чотирьохсо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "чотирьохсо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "чотирьохсо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "чотирьохсо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "чотирьохсо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "чотирьохсо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "чотирьохсо́тим"),
    (dict(case="instrumental", number="plural"), "чотирьохсо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "чотирьохсо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "чотирьохсо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "чотирьохсо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "чотирьохсо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "чотирьохсо́тім"),
    (dict(case="locative", number="plural"), "чотирьохсо́тих"),
  ], dict()),
  "500": ([
    (dict(case="nominative", number="singular", gender="masculine"), "пʼятисо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "пʼятисо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "пʼятисо́те"),
    (dict(case="nominative", number="plural"), "пʼятисо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "пʼятисо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "пʼятисо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "пʼятисо́те"),
    (dict(case="vocative", number="plural"), "пʼятисо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "пʼятисо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "пʼятисо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "пʼятисо́того"),
    (dict(case="genitive", number="plural"), "пʼятисо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "пʼятисо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "пʼятисо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "пʼятисо́тому"),
    (dict(case="dative", number="plural"), "пʼятисо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "пʼятисо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "пʼятисо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "пʼятисо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "пʼятисо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "пʼятисо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "пʼятисо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "пʼятисо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "пʼятисо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "пʼятисо́тим"),
    (dict(case="instrumental", number="plural"), "пʼятисо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятисо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "пʼятисо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "пʼятисо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятисо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "пʼятисо́тім"),
    (dict(case="locative", number="plural"), "пʼятисо́тих"),
  ], dict()),
  "600": ([
    (dict(case="nominative", number="singular", gender="masculine"), "шестисо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "шестисо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "шестисо́те"),
    (dict(case="nominative", number="plural"), "шестисо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "шестисо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "шестисо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "шестисо́те"),
    (dict(case="vocative", number="plural"), "шестисо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "шестисо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "шестисо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "шестисо́того"),
    (dict(case="genitive", number="plural"), "шестисо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "шестисо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "шестисо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "шестисо́тому"),
    (dict(case="dative", number="plural"), "шестисо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "шестисо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "шестисо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "шестисо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "шестисо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "шестисо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "шестисо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "шестисо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "шестисо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "шестисо́тим"),
    (dict(case="instrumental", number="plural"), "шестисо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "шестисо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "шестисо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "шестисо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "шестисо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "шестисо́тім"),
    (dict(case="locative", number="plural"), "шестисо́тих"),
  ], dict()),
  "700": ([
    (dict(case="nominative", number="singular", gender="masculine"), "семисо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "семисо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "семисо́те"),
    (dict(case="nominative", number="plural"), "семисо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "семисо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "семисо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "семисо́те"),
    (dict(case="vocative", number="plural"), "семисо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "семисо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "семисо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "семисо́того"),
    (dict(case="genitive", number="plural"), "семисо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "семисо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "семисо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "семисо́тому"),
    (dict(case="dative", number="plural"), "семисо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "семисо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "семисо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "семисо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "семисо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "семисо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "семисо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "семисо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "семисо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "семисо́тим"),
    (dict(case="instrumental", number="plural"), "семисо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "семисо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "семисо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "семисо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "семисо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "семисо́тім"),
    (dict(case="locative", number="plural"), "семисо́тих"),
  ], dict()),
  "800": ([
    (dict(case="nominative", number="singular", gender="masculine"), "восьмисо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "восьмисо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "восьмисо́те"),
    (dict(case="nominative", number="plural"), "восьмисо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "восьмисо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "восьмисо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "восьмисо́те"),
    (dict(case="vocative", number="plural"), "восьмисо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "восьмисо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "восьмисо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "восьмисо́того"),
    (dict(case="genitive", number="plural"), "восьмисо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "восьмисо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "восьмисо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "восьмисо́тому"),
    (dict(case="dative", number="plural"), "восьмисо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "восьмисо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "восьмисо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "восьмисо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "восьмисо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "восьмисо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "восьмисо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "восьмисо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "восьмисо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "восьмисо́тим"),
    (dict(case="instrumental", number="plural"), "восьмисо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "восьмисо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "восьмисо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "восьмисо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "восьмисо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "восьмисо́тім"),
    (dict(case="locative", number="plural"), "восьмисо́тих"),
  ], dict()),
  "900": ([
    (dict(case="nominative", number="singular", gender="masculine"), "девʼятисо́тий"),
    (dict(case="nominative", number="singular", gender="feminine"), "девʼятисо́та"),
    (dict(case="nominative", number="singular", gender="neuter"), "девʼятисо́те"),
    (dict(case="nominative", number="plural"), "девʼятисо́ті"),
    (dict(case="vocative", number="singular", gender="masculine"), "девʼятисо́тий"),
    (dict(case="vocative", number="singular", gender="feminine"), "девʼятисо́та"),
    (dict(case="vocative", number="singular", gender="neuter"), "девʼятисо́те"),
    (dict(case="vocative", number="plural"), "девʼятисо́ті"),
    (dict(case="genitive", number="singular", gender="masculine"), "девʼятисо́того"),
    (dict(case="genitive", number="singular", gender="feminine"), "девʼятисо́тої"),
    (dict(case="genitive", number="singular", gender="neuter"), "девʼятисо́того"),
    (dict(case="genitive", number="plural"), "девʼятисо́тих"),
    (dict(case="dative", number="singular", gender="masculine"), "девʼятисо́тому"),
    (dict(case="dative", number="singular", gender="feminine"), "девʼятисо́тій"),
    (dict(case="dative", number="singular", gender="neuter"), "девʼятисо́тому"),
    (dict(case="dative", number="plural"), "девʼятисо́тим"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "девʼятисо́тий"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "девʼятисо́того"),
    (dict(case="accusative", number="singular", gender="feminine"), "девʼятисо́ту"),
    (dict(case="accusative", number="singular", gender="neuter"), "девʼятисо́те"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "девʼятисо́ті"),
    (dict(case="accusative", number="plural", animacy="animate"), "девʼятисо́тих"),
    (dict(case="instrumental", number="singular", gender="masculine"), "девʼятисо́тим"),
    (dict(case="instrumental", number="singular", gender="feminine"), "девʼятисо́тою"),
    (dict(case="instrumental", number="singular", gender="neuter"), "девʼятисо́тим"),
    (dict(case="instrumental", number="plural"), "девʼятисо́тими"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼятисо́тому"),
    (dict(case="locative", number="singular", gender="masculine"), "девʼятисо́тім"),
    (dict(case="locative", number="singular", gender="feminine"), "девʼятисо́тій"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼятисо́тому"),
    (dict(case="locative", number="singular", gender="neuter"), "девʼятисо́тім"),
    (dict(case="locative", number="plural"), "девʼятисо́тих"),
  ], dict()),
  "1000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "ти́сячний"),
    (dict(case="nominative", number="singular", gender="feminine"), "ти́сячна"),
    (dict(case="nominative", number="singular", gender="neuter"), "ти́сячне"),
    (dict(case="nominative", number="plural"), "ти́сячні"),
    (dict(case="vocative", number="singular", gender="masculine"), "ти́сячний"),
    (dict(case="vocative", number="singular", gender="feminine"), "ти́сячна"),
    (dict(case="vocative", number="singular", gender="neuter"), "ти́сячне"),
    (dict(case="vocative", number="plural"), "ти́сячні"),
    (dict(case="genitive", number="singular", gender="masculine"), "ти́сячного"),
    (dict(case="genitive", number="singular", gender="feminine"), "ти́сячної"),
    (dict(case="genitive", number="singular", gender="neuter"), "ти́сячного"),
    (dict(case="genitive", number="plural"), "ти́сячних"),
    (dict(case="dative", number="singular", gender="masculine"), "ти́сячному"),
    (dict(case="dative", number="singular", gender="feminine"), "ти́сячній"),
    (dict(case="dative", number="singular", gender="neuter"), "ти́сячному"),
    (dict(case="dative", number="plural"), "ти́сячним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "ти́сячний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "ти́сячного"),
    (dict(case="accusative", number="singular", gender="feminine"), "ти́сячну"),
    (dict(case="accusative", number="singular", gender="neuter"), "ти́сячне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "ти́сячні"),
    (dict(case="accusative", number="plural", animacy="animate"), "ти́сячних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "ти́сячним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "ти́сячною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "ти́сячним"),
    (dict(case="instrumental", number="plural"), "ти́сячними"),
    (dict(case="locative", number="singular", gender="masculine"), "ти́сячному"),
    (dict(case="locative", number="singular", gender="masculine"), "ти́сячнім"),
    (dict(case="locative", number="singular", gender="feminine"), "ти́сячній"),
    (dict(case="locative", number="singular", gender="neuter"), "ти́сячному"),
    (dict(case="locative", number="singular", gender="neuter"), "ти́сячнім"),
    (dict(case="locative", number="plural"), "ти́сячних"),
  ], dict()),
  "1000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "мільйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "мільйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "мільйо́нне"),
    (dict(case="nominative", number="plural"), "мільйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "мільйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "мільйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "мільйо́нне"),
    (dict(case="vocative", number="plural"), "мільйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "мільйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "мільйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "мільйо́нного"),
    (dict(case="genitive", number="plural"), "мільйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "мільйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "мільйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "мільйо́нному"),
    (dict(case="dative", number="plural"), "мільйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "мільйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "мільйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "мільйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "мільйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "мільйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "мільйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "мільйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "мільйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "мільйо́нним"),
    (dict(case="instrumental", number="plural"), "мільйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "мільйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "мільйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "мільйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "мільйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "мільйо́ннім"),
    (dict(case="locative", number="plural"), "мільйо́нних"),
  ], dict()),
  "1000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "мілья́рдний"),
    (dict(case="nominative", number="singular", gender="feminine"), "мілья́рдна"),
    (dict(case="nominative", number="singular", gender="neuter"), "мілья́рдне"),
    (dict(case="nominative", number="plural"), "мілья́рдні"),
    (dict(case="vocative", number="singular", gender="masculine"), "мілья́рдний"),
    (dict(case="vocative", number="singular", gender="feminine"), "мілья́рдна"),
    (dict(case="vocative", number="singular", gender="neuter"), "мілья́рдне"),
    (dict(case="vocative", number="plural"), "мілья́рдні"),
    (dict(case="genitive", number="singular", gender="masculine"), "мілья́рдного"),
    (dict(case="genitive", number="singular", gender="feminine"), "мілья́рдної"),
    (dict(case="genitive", number="singular", gender="neuter"), "мілья́рдного"),
    (dict(case="genitive", number="plural"), "мілья́рдних"),
    (dict(case="dative", number="singular", gender="masculine"), "мілья́рдному"),
    (dict(case="dative", number="singular", gender="feminine"), "мілья́рдній"),
    (dict(case="dative", number="singular", gender="neuter"), "мілья́рдному"),
    (dict(case="dative", number="plural"), "мілья́рдним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "мілья́рдний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "мілья́рдного"),
    (dict(case="accusative", number="singular", gender="feminine"), "мілья́рдну"),
    (dict(case="accusative", number="singular", gender="neuter"), "мілья́рдне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "мілья́рдні"),
    (dict(case="accusative", number="plural", animacy="animate"), "мілья́рдних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "мілья́рдним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "мілья́рдною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "мілья́рдним"),
    (dict(case="instrumental", number="plural"), "мілья́рдними"),
    (dict(case="locative", number="singular", gender="masculine"), "мілья́рдному"),
    (dict(case="locative", number="singular", gender="masculine"), "мілья́рднім"),
    (dict(case="locative", number="singular", gender="feminine"), "мілья́рдній"),
    (dict(case="locative", number="singular", gender="neuter"), "мілья́рдному"),
    (dict(case="locative", number="singular", gender="neuter"), "мілья́рднім"),
    (dict(case="locative", number="plural"), "мілья́рдних"),
  ], dict()),
  "1000000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "трильйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "трильйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "трильйо́нне"),
    (dict(case="nominative", number="plural"), "трильйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "трильйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "трильйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "трильйо́нне"),
    (dict(case="vocative", number="plural"), "трильйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "трильйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "трильйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "трильйо́нного"),
    (dict(case="genitive", number="plural"), "трильйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "трильйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "трильйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "трильйо́нному"),
    (dict(case="dative", number="plural"), "трильйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "трильйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "трильйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "трильйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "трильйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "трильйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "трильйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "трильйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "трильйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "трильйо́нним"),
    (dict(case="instrumental", number="plural"), "трильйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "трильйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "трильйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "трильйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "трильйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "трильйо́ннім"),
    (dict(case="locative", number="plural"), "трильйо́нних"),
  ], dict()),
  "1000000000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "квадрильйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "квадрильйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "квадрильйо́нне"),
    (dict(case="nominative", number="plural"), "квадрильйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "квадрильйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "квадрильйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "квадрильйо́нне"),
    (dict(case="vocative", number="plural"), "квадрильйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "квадрильйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "квадрильйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "квадрильйо́нного"),
    (dict(case="genitive", number="plural"), "квадрильйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "квадрильйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "квадрильйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "квадрильйо́нному"),
    (dict(case="dative", number="plural"), "квадрильйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "квадрильйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "квадрильйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "квадрильйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "квадрильйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "квадрильйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "квадрильйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "квадрильйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "квадрильйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "квадрильйо́нним"),
    (dict(case="instrumental", number="plural"), "квадрильйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "квадрильйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "квадрильйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "квадрильйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "квадрильйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "квадрильйо́ннім"),
    (dict(case="locative", number="plural"), "квадрильйо́нних"),
  ], dict()),
  "1000000000000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "квінтильйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "квінтильйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "квінтильйо́нне"),
    (dict(case="nominative", number="plural"), "квінтильйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "квінтильйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "квінтильйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "квінтильйо́нне"),
    (dict(case="vocative", number="plural"), "квінтильйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "квінтильйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "квінтильйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "квінтильйо́нного"),
    (dict(case="genitive", number="plural"), "квінтильйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "квінтильйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "квінтильйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "квінтильйо́нному"),
    (dict(case="dative", number="plural"), "квінтильйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "квінтильйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "квінтильйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "квінтильйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "квінтильйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "квінтильйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "квінтильйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "квінтильйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "квінтильйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "квінтильйо́нним"),
    (dict(case="instrumental", number="plural"), "квінтильйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "квінтильйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "квінтильйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "квінтильйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "квінтильйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "квінтильйо́ннім"),
    (dict(case="locative", number="plural"), "квінтильйо́нних"),
  ], dict()),
  "1000000000000000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "секстильйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "секстильйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "секстильйо́нне"),
    (dict(case="nominative", number="plural"), "секстильйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "секстильйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "секстильйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "секстильйо́нне"),
    (dict(case="vocative", number="plural"), "секстильйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "секстильйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "секстильйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "секстильйо́нного"),
    (dict(case="genitive", number="plural"), "секстильйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "секстильйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "секстильйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "секстильйо́нному"),
    (dict(case="dative", number="plural"), "секстильйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "секстильйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "секстильйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "секстильйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "секстильйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "секстильйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "секстильйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "секстильйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "секстильйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "секстильйо́нним"),
    (dict(case="instrumental", number="plural"), "секстильйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "секстильйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "секстильйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "секстильйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "секстильйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "секстильйо́ннім"),
    (dict(case="locative", number="plural"), "секстильйо́нних"),
  ], dict()),
  "1000000000000000000000000": ([
    (dict(case="nominative", number="singular", gender="masculine"), "септильйо́нний"),
    (dict(case="nominative", number="singular", gender="feminine"), "септильйо́нна"),
    (dict(case="nominative", number="singular", gender="neuter"), "септильйо́нне"),
    (dict(case="nominative", number="plural"), "септильйо́нні"),
    (dict(case="vocative", number="singular", gender="masculine"), "септильйо́нний"),
    (dict(case="vocative", number="singular", gender="feminine"), "септильйо́нна"),
    (dict(case="vocative", number="singular", gender="neuter"), "септильйо́нне"),
    (dict(case="vocative", number="plural"), "септильйо́нні"),
    (dict(case="genitive", number="singular", gender="masculine"), "септильйо́нного"),
    (dict(case="genitive", number="singular", gender="feminine"), "септильйо́нної"),
    (dict(case="genitive", number="singular", gender="neuter"), "септильйо́нного"),
    (dict(case="genitive", number="plural"), "септильйо́нних"),
    (dict(case="dative", number="singular", gender="masculine"), "септильйо́нному"),
    (dict(case="dative", number="singular", gender="feminine"), "септильйо́нній"),
    (dict(case="dative", number="singular", gender="neuter"), "септильйо́нному"),
    (dict(case="dative", number="plural"), "септильйо́нним"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="inanimate"), "септильйо́нний"),
    (dict(case="accusative", number="singular", gender="masculine", animacy="animate"), "септильйо́нного"),
    (dict(case="accusative", number="singular", gender="feminine"), "септильйо́нну"),
    (dict(case="accusative", number="singular", gender="neuter"), "септильйо́нне"),
    (dict(case="accusative", number="plural", animacy="inanimate"), "септильйо́нні"),
    (dict(case="accusative", number="plural", animacy="animate"), "септильйо́нних"),
    (dict(case="instrumental", number="singular", gender="masculine"), "септильйо́нним"),
    (dict(case="instrumental", number="singular", gender="feminine"), "септильйо́нною"),
    (dict(case="instrumental", number="singular", gender="neuter"), "септильйо́нним"),
    (dict(case="instrumental", number="plural"), "септильйо́нними"),
    (dict(case="locative", number="singular", gender="masculine"), "септильйо́нному"),
    (dict(case="locative", number="singular", gender="masculine"), "септильйо́ннім"),
    (dict(case="locative", number="singular", gender="feminine"), "септильйо́нній"),
    (dict(case="locative", number="singular", gender="neuter"), "септильйо́нному"),
    (dict(case="locative", number="singular", gender="neuter"), "септильйо́ннім"),
    (dict(case="locative", number="plural"), "септильйо́нних"),
  ], dict()),
}
